<?php
/**
* Display the meetingpoint
*
* Displays a meetingpoint in a popup.
*
*/
    require_once("../../config.php");
    
    $id = optional_param('id', '', PARAM_INT);       // Course Module ID, or
    $a = optional_param('a', '', PARAM_INT);         // meeting ID

    if (!empty($id)) {
        if (! $cm = get_coursemodule_from_id('meetingpoint', $id)) {
            error("Course Module ID was incorrect");
        }
        if (! $course = get_record("course", "id", $cm->course)) {
            error("Course is misconfigured");
        }
        if (! $meetingpoint = get_record("meetingpoint", "id", $cm->instance)) {
            error("Course module is incorrect");
        }
    } else if (!empty($a)) {
        if (! $meetingpoint = get_record("meetingpoint", "id", $a)) {
            error("Course module is incorrect");
        }
        if (! $course = get_record("course", "id", $meetingpoint->course)) {
            error("Course is misconfigured");
        }
        if (! $cm = get_coursemodule_from_instance("meetingpoint", $meetingpoint->id, $course->id)) {
            error("Course Module ID was incorrect");
        }
    } else {
        error('A required parameter is missing');
    }

    require_login($course->id, false, $cm);

    $context = get_context_instance(CONTEXT_COURSE, $course->id);
    
    $pagetitle = strip_tags($course->shortname.': '.format_string($meetingpoint->name));

    $strmeetingpoint = get_string('modulename','meetingpoint');
    $strmeetingpoints = get_string('modulenameplural','meetingpoint');

    $navigation = build_navigation('', $cm);

    if (!$cm->visible and !has_capability('moodle/course:viewhiddenactivities', get_context_instance(CONTEXT_MODULE, $cm->id))) {
        $pagetitle = strip_tags($course->shortname.': '.$strmeetingpoint);
        print_header($pagetitle, $course->fullname, $navigation, "", "", true, '', navmenu($course, $cm));
        notice(get_string("activityiscurrentlyhidden"), "$CFG->wwwroot/course/view.php?id={$course->id}");
    }
    
    if ($cm->visible and !has_capability('mod/meetingpoint:view', get_context_instance(CONTEXT_MODULE, $cm->id))) {
        $pagetitle = strip_tags($course->shortname.': '.$strmeetingpoint);
        print_header($pagetitle, $course->fullname, $navigation, "", "", true, '', navmenu($course, $cm));
        notice(get_string('viewnotallowed','meetingpoint'), "$CFG->wwwroot/course/view.php?id={$course->id}");
    }

    /// Set up some variables

    $inpopup = optional_param('inpopup', 0, PARAM_BOOL);

    $baseurl = $CFG->wwwroot.'/mod/meetingpoint/swf/';
    $meetingpointswf = 'meetingpoint.swf';

    // Make a page and a pop-up window
    if (!$inpopup) {
        print_header($pagetitle, $course->fullname, $navigation, "", "", true, update_module_button($cm->id, $course->id, $strmeetingpoint), navmenu($course, $cm));
    
        $popup = 'width=800,height=600,resizable=yes,location=no,status=no,toolbar=no,menubar=no,directories=no';
        $fullscreen = 'false';
    
        echo "\n<script type=\"text/javascript\">";
        echo "\n//<![CDATA[\n";
        echo "  var win=openpopup('/mod/meetingpoint/view.php?inpopup=true&id={$cm->id}','meeting{$meetingpoint->id}','{$popup}',{$fullscreen});";
        echo "\n//]]>\n";
        echo '</script>';
    
        if (trim(strip_tags($meetingpoint->summary))) {
            $formatoptions = new object();
            $formatoptions->noclean = true;
            print_simple_box(format_text($meetingpoint->summary, FORMAT_MOODLE, $formatoptions), "center");
        }
    
        $link = "<a href=\"$CFG->wwwroot/mod/meetingpoint/view.php?inpopup=true&amp;id={$cm->id}\" onclick=\"this.target='meeting{$meetingpoint->id}'; return openpopup('/mod/meetingpoint/view.php?inpopup=true&amp;id={$cm->id}', 'meeting{$meetingpoint->id}','{$popup}',{$fullscreen});\">".format_string($meetingpoint->name,true)."</a>";

        echo '<div class="popupnotice">';
        print_string('popupmeeting', 'meetingpoint');
        echo '<br />';
        print_string('popupmeetinglink', 'meetingpoint', $link);
        echo '</div>';
    
        if (has_capability('moodle/course:manageactivities', get_context_instance(CONTEXT_MODULE, $cm->id))) {
            echo '<br />';
            print_simple_box('<a href="" onclick="return openpopup(\'/mod/meetingpoint/files/index.php?id='.$meetingpoint->course.'\', \'popup\', \'width=750,height=500,scrollbars,resizable\');" >'.get_string('filemanager','meetingpoint').'</a>', 'center');
        }

        print_footer($course);
        exit;
    }

    /// Display the actual meeting

    if ($inpopup) {
        print_header($pagetitle);

        /// We can only get here once per meeting, so add an entry to the log

        add_to_log($course->id, "meetingpoint", "view", "view.php?id={$cm->id}", $meetingpoint->id, $cm->id);

    } else {
        print_header($pagetitle, $course->fullname, $navigation, "", "", true, update_module_button($cm->id, $course->id, $strmeetingpoint), navmenu($course, $cm, "self"));

    }


    $c = 'xmlfile='.urlencode($CFG->wwwroot.'/mod/meetingpoint/mp.xml.php?id='.$cm->id.'&sesskey='.$USER->sesskey);
    $fullurl = $baseurl.$meetingpointswf;

    echo '<div id="meetingpoint">'."\n";
    echo '  <object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"'."\n";
    //echo '          srctype="application/x-shockwave-flash" '."\n";
    //echo '          data="'.$fullurl.'" '."\n";
    //echo '          base="'.$baseurl.'" '."\n";
    //echo '          data="'.$fullurl.'" '."\n";
    echo '          codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=9,0,0,0" '."\n";
    echo '          width="100%" height="99%" id="meeting" >'."\n";
    echo '    <param name="base" value="'.$baseurl.'" />'."\n";
    echo '    <param name="movie" value="'.$fullurl.'" />'."\n";
    echo '    <param name="quality" value="high" />'."\n";
    echo '    <param name="allowfullscreen" value="true" />'."\n";
    echo '    <param name="flashvars" value="'.$c.'" />'."\n";
    echo '<embed src="'.$fullurl.'" '."\n";
    echo ' quality="high" width="100%" height="99%" name="meeting" '."\n";
    echo ' type="application/x-shockwave-flash" '."\n";
    echo ' base="'.$baseurl.'" '."\n";
    echo ' allowfullscreen="true" '."\n";
    echo ' flashvars="'.$c.'" '."\n";
    echo ' pluginspage="http://www.macromedia.com/go/getflashplayer">'."\n";
    echo '</embed>'."\n";
    echo '  </object>'."\n";
    echo '</div>'."\n";


    if (!$inpopup) {
        print_spacer(20,20);
        print_footer($course);
    } else {
        echo '</div></div></body></html>';
    }

?>
